@@ -62,6 +62,9 @@ INTERNALERROR_CLUSTERSTATE = 'InternalError.ClusterState'
 # 集群节点版本过低。
 INTERNALERROR_CLUSTERUPGRADENODEVERSION = 'InternalError.ClusterUpgradeNodeVersion'
 
+# 执行命令超时。
+INTERNALERROR_CMDTIMEOUT = 'InternalError.CmdTimeout'
+
 # 内部HTTP客户端错误。
 INTERNALERROR_COMPONENTCLIENTHTTP = 'InternalError.ComponentClientHttp'
 
@@ -206,6 +209,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 弹性伸缩组创建参数错误。
 INVALIDPARAMETER_ASCOMMONERROR = 'InvalidParameter.AsCommonError'
 
+# CIDR掩码超出范围(集群CIDR范围 最小值: 10 最大值: 24)。
+INVALIDPARAMETER_CIDRMASKSIZEOUTOFRANGE = 'InvalidParameter.CIDRMaskSizeOutOfRange'
+
 # CIDR和其他集群CIDR冲突。
 INVALIDPARAMETER_CIDRCONFLICTWITHOTHERCLUSTER = 'InvalidParameter.CidrConflictWithOtherCluster'
 
